@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.1504';
+our $VERSION = '0.1505';
 
 use Moo;
 use strictures 2;
@@ -316,7 +316,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.1504
+version 0.1505
 
 =head1 SYNOPSIS
 
@@ -326,27 +326,27 @@ version 0.1504
   my $opinion = Lingua::EN::Opinion->new( file => '/some/file.txt', stem => 1 );
   $opinion->analyze();
 
-  # Now you can process $opinion->scores...
+  my $scores = $opinion->scores;
 
   my $ratio = $opinion->ratio(); # Knowns / ( Knowns + Unknowns )
   $ratio = $opinion->ratio(1); # Unknowns / ( Knowns + Unknowns )
 
-  my $score = $opinion->averaged_score(5);
+  $scores = $opinion->averaged_score(5);
 
-  my $sentiment = $opinion->get_word('foo');
-  $sentiment = $opinion->get_sentence('Mary had a little lamb.');
+  my $score = $opinion->get_word('foo');
+  $score = $opinion->get_sentence('Mary had a little lamb.');
 
   # NRC:
   $opinion = Lingua::EN::Opinion->new( text => 'Mary had a little lamb...' );
   $opinion->nrc_sentiment();
 
-  # Now you can process $opinion->nrc_scores...
+  $scores = $opinion->nrc_scores;
 
   $ratio = $opinion->ratio();
   $ratio = $opinion->ratio(1);
 
-  $sentiment = $opinion->nrc_get_word('foo');
-  $sentiment = $opinion->nrc_get_sentence('Mary had a little lamb.');
+  $score = $opinion->nrc_get_word('foo');
+  $score = $opinion->nrc_get_sentence('Mary had a little lamb.');
 
 =head1 DESCRIPTION
 
